[QGIS Commit] r11879 - in trunk/qgis/src: app gui

svn_qgis at osgeo.org svn_qgis at osgeo.org
Sun Nov 1 16:24:54 EST 2009


Author: timlinux
Date: 2009-11-01 16:24:54 -0500 (Sun, 01 Nov 2009)
New Revision: 11879

Modified:
   trunk/qgis/src/app/qgslabeldialog.cpp
   trunk/qgis/src/gui/qgsquickprint.cpp
Log:
Use labelAttributes rather than layerAttributes where appropriate

Modified: trunk/qgis/src/app/qgslabeldialog.cpp
===================================================================
--- trunk/qgis/src/gui/qgsquickprint.cpp	2009-11-01 16:32:39 UTC (rev 11878)
+++ trunk/qgis/src/gui/qgsquickprint.cpp	2009-11-01 21:24:54 UTC (rev 11879)
@@ -688,7 +688,7 @@
       if ( mypVectorLayer )
       {
         QgsLabel * mypLabel = mypVectorLayer->label();
-        QgsLabelAttributes * mypLabelAttributes = mypLabel->layerAttributes();
+        QgsLabelAttributes * mypLabelAttributes = mypLabel->labelAttributes();
         if ( theDirection == ScaleUp )
         {
           mypLabelAttributes->setSize(



More information about the QGIS-commit mailing list
--- trunk/qgis/src/app/qgslabeldialog.cpp	2009-11-01 16:32:39 UTC (rev 11878)
+++ trunk/qgis/src/app/qgslabeldialog.cpp	2009-11-01 21:24:54 UTC (rev 11879)
@@ -55,7 +55,7 @@
 {
   QgsDebugMsg( "entering." );
 
-  QgsLabelAttributes * myLabelAttributes = mLabel->layerAttributes();
+  QgsLabelAttributes * myLabelAttributes = mLabel->labelAttributes();
   //populate a string list with all the field names which will be used to set up the
   //data bound combos
   QgsFieldMap& myFieldsMap = mLabel->fields();
@@ -340,8 +340,8 @@
   QgsDebugMsg( "entering." );
 
   //set the label props that are NOT bound to a field in the attributes tbl
-  //All of these are set in the layerAttributes member of the layer
-  QgsLabelAttributes * myLabelAttributes = mLabel->layerAttributes();
+  //All of these are set in the labelAttributes member of the layer
+  QgsLabelAttributes * myLabelAttributes = mLabel->labelAttributes();
   myLabelAttributes->setText( leDefaultLabel->text() );
   myLabelAttributes->setFamily( mFont.family() );
   int myTypeInt = 0;

Modified: trunk/qgis/src/gui/qgsquickprint.cpp
===================================================================